@@ -229,7 +229,11 @@ class ElectronGunControl:
             remainingRetries = 0
 
         while self.messageResponse == None:
-            if not self.messageConditionVariable.wait(timeout = 10):
+            if self.messageFilter == "beamon":
+                mytimeout = 120
+            else:
+                mytimeout = 10
+            if not self.messageConditionVariable.wait(timeout = mytimeout):
                 print(f"Timeout while waiting for {self.messageFilter} (Retries remaining: {remainingRetries})")
                 if (remainingRetries > 0) and (self._lastcommand is not None):
                     # Retry command ...
@@ -699,7 +703,7 @@ class ElectronGunControl:
         except ValueError:
             raise ElectronGunInvalidParameterException("Filament current has to be an integer in range 0 to 100 mA")
 
-        cmd = b'$$$setfila' + bytes(str(currentMa), encoding="ascii") + b'\n'
+        cmd = b'$$$setfila' + bytes(str(currentMa * 10.0), encoding="ascii") + b'\n'
         self.port.write(cmd)
         self._lastcommand = cmd
 
